#include "../../controller/callbacks/reshape.h"
#include "../../view/state0.h"
#include "density_legend_geometry.h"
#include <GL/glut.h>

#define S state0

void
density_legend_geometry (void)
{
  glNewList (S.list_offset + DENSITY_LEGEND_GEOMETRY, GL_COMPILE);
  glPolygonMode (GL_FRONT, GL_FILL);
  glColor4f (DEFAULT_COLOR_R, DEFAULT_COLOR_G, DEFAULT_COLOR_B,
	     DEFAULT_COLOR_A);

  /*
   * Calculate the bounding box for the legend.
   */

  double a[2];
  double b[2];
  double c[2];
  double d[2];

  const double *left = &S.ortho.min_x;
  const double *right = &S.ortho.max_x;
  const double *top = &S.ortho.max_y;
  const double *bottom = &S.ortho.min_y;

  /*
   * This value should be a percentage of the world height so that it
   * remains a fixed number of pixels tall when the window is resized
   * or zoomed.
   */
  GLint viewport[4];
  glGetIntegerv (GL_VIEWPORT, viewport);

  double legend_height = (*top - *bottom) / viewport[3] * 10.0;

  a[0] = *left;
  a[1] = *top;
  b[0] = *right;
  b[1] = *top;
  c[0] = *right;
  c[1] = *top - legend_height;
  d[0] = *left;
  d[1] = *top - legend_height;

  /*
   * Overlay a legend from default saturation / alpha to full saturation.
   */
  for (int i = 1; i <= 1 / DEFAULT_COLOR_A; i++)
    {
      glBegin (GL_QUADS);
      glVertex2dv (a);
      glVertex2dv (b);
      glVertex2dv (c);
      glVertex2dv (d);
      glEnd ();

      /*
       * Step left to right along the x-coordinate.
       */
      a[0] = *left + (*right - *left) * (DEFAULT_COLOR_A * i);
      d[0] = a[0];
    }

  glEndList ();

  return;
}
